# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from pulpcore.client.pulp_ansible.models.policy_enum import PolicyEnum
from typing import Optional, Set
from typing_extensions import Self


class OneOf:
    @staticmethod
    def from_dict(obj, *args, **kwargs):
        """Noop override to fix missing OneOf import/implementation."""
        return obj


class AnsibleRoleRemote(BaseModel):
    """
    A serializer for Ansible Remotes.
    """ # noqa: E501
    name: Annotated[str, Field(min_length=1, strict=True)] = Field(description="A unique name for this remote.")
    url: Annotated[str, Field(min_length=1, strict=True)] = Field(description="The URL of an external content source.")
    ca_cert: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="A PEM encoded CA certificate used to validate the server certificate presented by the remote server.")
    client_cert: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="A PEM encoded client certificate used for authentication.")
    client_key: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="A PEM encoded private key used for authentication.")
    tls_validation: Optional[StrictBool] = Field(default=None, description="If True, TLS peer validation must be performed.")
    proxy_url: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The proxy URL. Format: scheme://host:port")
    proxy_username: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The username to authenticte to the proxy.")
    proxy_password: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The password to authenticate to the proxy. Extra leading and trailing whitespace characters are not trimmed.")
    username: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The username to be used for authentication when syncing.")
    password: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The password to be used for authentication when syncing. Extra leading and trailing whitespace characters are not trimmed.")
    pulp_labels: Optional[Dict[str, Optional[StrictStr]]] = None
    download_concurrency: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, description="Total number of simultaneous connections. If not set then the default value will be used.")
    max_retries: Optional[StrictInt] = Field(default=None, description="Maximum number of retry attempts after a download failure. If not set then the default value (3) will be used.")
    policy: Optional[PolicyEnum] = Field(default=None, description="The policy to use when downloading content.  * `immediate` - When syncing, download all metadata and content now.")
    total_timeout: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=None, description="aiohttp.ClientTimeout.total (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.")
    connect_timeout: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=None, description="aiohttp.ClientTimeout.connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.")
    sock_connect_timeout: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=None, description="aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.")
    sock_read_timeout: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=None, description="aiohttp.ClientTimeout.sock_read (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.")
    headers: Optional[List[Dict[str, Any]]] = Field(default=None, description="Headers for aiohttp.Clientsession")
    rate_limit: Optional[StrictInt] = Field(default=None, description="Limits requests per second for each concurrent downloader")
    __properties: ClassVar[List[str]] = ["name", "url", "ca_cert", "client_cert", "client_key", "tls_validation", "proxy_url", "proxy_username", "proxy_password", "username", "password", "pulp_labels", "download_concurrency", "max_retries", "policy", "total_timeout", "connect_timeout", "sock_connect_timeout", "sock_read_timeout", "headers", "rate_limit"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AnsibleRoleRemote from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if ca_cert (nullable) is None
        # and model_fields_set contains the field
        if self.ca_cert is None and "ca_cert" in self.model_fields_set:
            _dict['ca_cert'] = None

        # set to None if client_cert (nullable) is None
        # and model_fields_set contains the field
        if self.client_cert is None and "client_cert" in self.model_fields_set:
            _dict['client_cert'] = None

        # set to None if client_key (nullable) is None
        # and model_fields_set contains the field
        if self.client_key is None and "client_key" in self.model_fields_set:
            _dict['client_key'] = None

        # set to None if proxy_url (nullable) is None
        # and model_fields_set contains the field
        if self.proxy_url is None and "proxy_url" in self.model_fields_set:
            _dict['proxy_url'] = None

        # set to None if proxy_username (nullable) is None
        # and model_fields_set contains the field
        if self.proxy_username is None and "proxy_username" in self.model_fields_set:
            _dict['proxy_username'] = None

        # set to None if proxy_password (nullable) is None
        # and model_fields_set contains the field
        if self.proxy_password is None and "proxy_password" in self.model_fields_set:
            _dict['proxy_password'] = None

        # set to None if username (nullable) is None
        # and model_fields_set contains the field
        if self.username is None and "username" in self.model_fields_set:
            _dict['username'] = None

        # set to None if password (nullable) is None
        # and model_fields_set contains the field
        if self.password is None and "password" in self.model_fields_set:
            _dict['password'] = None

        # set to None if download_concurrency (nullable) is None
        # and model_fields_set contains the field
        if self.download_concurrency is None and "download_concurrency" in self.model_fields_set:
            _dict['download_concurrency'] = None

        # set to None if max_retries (nullable) is None
        # and model_fields_set contains the field
        if self.max_retries is None and "max_retries" in self.model_fields_set:
            _dict['max_retries'] = None

        # set to None if total_timeout (nullable) is None
        # and model_fields_set contains the field
        if self.total_timeout is None and "total_timeout" in self.model_fields_set:
            _dict['total_timeout'] = None

        # set to None if connect_timeout (nullable) is None
        # and model_fields_set contains the field
        if self.connect_timeout is None and "connect_timeout" in self.model_fields_set:
            _dict['connect_timeout'] = None

        # set to None if sock_connect_timeout (nullable) is None
        # and model_fields_set contains the field
        if self.sock_connect_timeout is None and "sock_connect_timeout" in self.model_fields_set:
            _dict['sock_connect_timeout'] = None

        # set to None if sock_read_timeout (nullable) is None
        # and model_fields_set contains the field
        if self.sock_read_timeout is None and "sock_read_timeout" in self.model_fields_set:
            _dict['sock_read_timeout'] = None

        # set to None if rate_limit (nullable) is None
        # and model_fields_set contains the field
        if self.rate_limit is None and "rate_limit" in self.model_fields_set:
            _dict['rate_limit'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AnsibleRoleRemote from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "url": obj.get("url"),
            "ca_cert": obj.get("ca_cert"),
            "client_cert": obj.get("client_cert"),
            "client_key": obj.get("client_key"),
            "tls_validation": obj.get("tls_validation"),
            "proxy_url": obj.get("proxy_url"),
            "proxy_username": obj.get("proxy_username"),
            "proxy_password": obj.get("proxy_password"),
            "username": obj.get("username"),
            "password": obj.get("password"),
            "pulp_labels": obj.get("pulp_labels"),
            "download_concurrency": obj.get("download_concurrency"),
            "max_retries": obj.get("max_retries"),
            "policy": obj.get("policy"),
            "total_timeout": obj.get("total_timeout"),
            "connect_timeout": obj.get("connect_timeout"),
            "sock_connect_timeout": obj.get("sock_connect_timeout"),
            "sock_read_timeout": obj.get("sock_read_timeout"),
            "headers": obj.get("headers"),
            "rate_limit": obj.get("rate_limit")
        })
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.models.paginated_collection_response_list import PaginatedCollectionResponseList

class TestPaginatedCollectionResponseList(unittest.TestCase):
    """PaginatedCollectionResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedCollectionResponseList:
        """Test PaginatedCollectionResponseList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedCollectionResponseList`
        """
        model = PaginatedCollectionResponseList()
        if include_optional:
            return PaginatedCollectionResponseList(
                meta = pulpcore.client.pulp_ansible.models.paginated_collection_response_list_meta.PaginatedCollectionResponseList_meta(
                    count = 123, ),
                links = pulpcore.client.pulp_ansible.models.paginated_collection_response_list_links.PaginatedCollectionResponseList_links(
                    first = '', 
                    previous = '', 
                    next = '', 
                    last = '', ),
                data = [
                    pulpcore.client.pulp_ansible.models.collection_response.CollectionResponse(
                        href = '', 
                        namespace = '', 
                        name = '', 
                        deprecated = True, 
                        versions_url = '', 
                        highest_version = pulpcore.client.pulp_ansible.models.highest_version.highest_version(), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        download_count = 56, )
                    ]
            )
        else:
            return PaginatedCollectionResponseList(
        )
        """

    def testPaginatedCollectionResponseList(self):
        """Test PaginatedCollectionResponseList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.25.5"

# import apis into sdk package
from pulpcore.client.pulp_ansible.api.ansible_collections_api import AnsibleCollectionsApi
from pulpcore.client.pulp_ansible.api.ansible_copy_api import AnsibleCopyApi
from pulpcore.client.pulp_ansible.api.api_plugin_ansible_search_collection_versions_api import ApiPluginAnsibleSearchCollectionVersionsApi
from pulpcore.client.pulp_ansible.api.api_roles_api import ApiRolesApi
from pulpcore.client.pulp_ansible.api.collection_import_api import CollectionImportApi
from pulpcore.client.pulp_ansible.api.content_collection_deprecations_api import ContentCollectionDeprecationsApi
from pulpcore.client.pulp_ansible.api.content_collection_marks_api import ContentCollectionMarksApi
from pulpcore.client.pulp_ansible.api.content_collection_signatures_api import ContentCollectionSignaturesApi
from pulpcore.client.pulp_ansible.api.content_collection_versions_api import ContentCollectionVersionsApi
from pulpcore.client.pulp_ansible.api.content_namespaces_api import ContentNamespacesApi
from pulpcore.client.pulp_ansible.api.content_roles_api import ContentRolesApi
from pulpcore.client.pulp_ansible.api.distributions_ansible_api import DistributionsAnsibleApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_api import PulpAnsibleApiApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_api import PulpAnsibleApiV3Api
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_artifacts_collections_api import PulpAnsibleApiV3ArtifactsCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collection_versions_all_api import PulpAnsibleApiV3CollectionVersionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_api import PulpAnsibleApiV3CollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_all_api import PulpAnsibleApiV3CollectionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_versions_api import PulpAnsibleApiV3CollectionsVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_versions_docs_blob_api import PulpAnsibleApiV3CollectionsVersionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_namespaces_api import PulpAnsibleApiV3NamespacesApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_client_configuration_api import PulpAnsibleApiV3PluginAnsibleClientConfigurationApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_all_collections_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsAllCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_all_versions_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsAllVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_artifacts_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsArtifactsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_index_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_index_versions_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_index_versions_docs_blob_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_namespaces_api import PulpAnsibleApiV3PluginAnsibleContentNamespacesApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_artifacts_collections_v3_api import PulpAnsibleArtifactsCollectionsV3Api
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_api import PulpAnsibleDefaultApiApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_api import PulpAnsibleDefaultApiV3Api
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_artifacts_collections_api import PulpAnsibleDefaultApiV3ArtifactsCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collection_versions_all_api import PulpAnsibleDefaultApiV3CollectionVersionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_api import PulpAnsibleDefaultApiV3CollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_all_api import PulpAnsibleDefaultApiV3CollectionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_versions_api import PulpAnsibleDefaultApiV3CollectionsVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_versions_docs_blob_api import PulpAnsibleDefaultApiV3CollectionsVersionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_namespaces_api import PulpAnsibleDefaultApiV3NamespacesApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_client_configuration_api import PulpAnsibleDefaultApiV3PluginAnsibleClientConfigurationApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_all_collections_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_all_versions_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_artifacts_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsArtifactsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_index_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_index_versions_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_index_versions_docs_blob_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_namespaces_api import PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_search_collection_versions_api import PulpAnsibleDefaultApiV3PluginAnsibleSearchCollectionVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_tags_api import PulpAnsibleTagsApi
from pulpcore.client.pulp_ansible.api.remotes_collection_api import RemotesCollectionApi
from pulpcore.client.pulp_ansible.api.remotes_git_api import RemotesGitApi
from pulpcore.client.pulp_ansible.api.remotes_role_api import RemotesRoleApi
from pulpcore.client.pulp_ansible.api.repositories_ansible_api import RepositoriesAnsibleApi
from pulpcore.client.pulp_ansible.api.repositories_ansible_versions_api import RepositoriesAnsibleVersionsApi
from pulpcore.client.pulp_ansible.api.versions_api import VersionsApi

# import ApiClient
from pulpcore.client.pulp_ansible.api_response import ApiResponse
from pulpcore.client.pulp_ansible.api_client import ApiClient
from pulpcore.client.pulp_ansible.configuration import Configuration
from pulpcore.client.pulp_ansible.exceptions import OpenApiException
from pulpcore.client.pulp_ansible.exceptions import ApiTypeError
from pulpcore.client.pulp_ansible.exceptions import ApiValueError
from pulpcore.client.pulp_ansible.exceptions import ApiKeyError
from pulpcore.client.pulp_ansible.exceptions import ApiAttributeError
from pulpcore.client.pulp_ansible.exceptions import ApiException

# import models into sdk package
from pulpcore.client.pulp_ansible.models.ansible_ansible_collection_deprecated import AnsibleAnsibleCollectionDeprecated
from pulpcore.client.pulp_ansible.models.ansible_ansible_collection_deprecated_response import AnsibleAnsibleCollectionDeprecatedResponse
from pulpcore.client.pulp_ansible.models.ansible_ansible_distribution import AnsibleAnsibleDistribution
from pulpcore.client.pulp_ansible.models.ansible_ansible_distribution_response import AnsibleAnsibleDistributionResponse
from pulpcore.client.pulp_ansible.models.ansible_ansible_namespace_metadata import AnsibleAnsibleNamespaceMetadata
from pulpcore.client.pulp_ansible.models.ansible_ansible_namespace_metadata_response import AnsibleAnsibleNamespaceMetadataResponse
from pulpcore.client.pulp_ansible.models.ansible_ansible_repository import AnsibleAnsibleRepository
from pulpcore.client.pulp_ansible.models.ansible_ansible_repository_response import AnsibleAnsibleRepositoryResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_remote import AnsibleCollectionRemote
from pulpcore.client.pulp_ansible.models.ansible_collection_remote_response import AnsibleCollectionRemoteResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_remote_response_hidden_fields_inner import AnsibleCollectionRemoteResponseHiddenFieldsInner
from pulpcore.client.pulp_ansible.models.ansible_collection_response import AnsibleCollectionResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_version_mark import AnsibleCollectionVersionMark
from pulpcore.client.pulp_ansible.models.ansible_collection_version_mark_response import AnsibleCollectionVersionMarkResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_version_response import AnsibleCollectionVersionResponse
from pulpcore.client.pulp_ansible.models.ansible_collection_version_signature_response import AnsibleCollectionVersionSignatureResponse
from pulpcore.client.pulp_ansible.models.ansible_git_remote import AnsibleGitRemote
from pulpcore.client.pulp_ansible.models.ansible_git_remote_response import AnsibleGitRemoteResponse
from pulpcore.client.pulp_ansible.models.ansible_repository_mark import AnsibleRepositoryMark
from pulpcore.client.pulp_ansible.models.ansible_repository_rebuild import AnsibleRepositoryRebuild
from pulpcore.client.pulp_ansible.models.ansible_repository_signature import AnsibleRepositorySignature
from pulpcore.client.pulp_ansible.models.ansible_repository_sync_url import AnsibleRepositorySyncURL
from pulpcore.client.pulp_ansible.models.ansible_role import AnsibleRole
from pulpcore.client.pulp_ansible.models.ansible_role_remote import AnsibleRoleRemote
from pulpcore.client.pulp_ansible.models.ansible_role_remote_response import AnsibleRoleRemoteResponse
from pulpcore.client.pulp_ansible.models.ansible_role_response import AnsibleRoleResponse
from pulpcore.client.pulp_ansible.models.ansible_tag_response import AnsibleTagResponse
from pulpcore.client.pulp_ansible.models.artifact_ref_response import ArtifactRefResponse
from pulpcore.client.pulp_ansible.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulp_ansible.models.client_configuration_response import ClientConfigurationResponse
from pulpcore.client.pulp_ansible.models.collection_import_detail_response import CollectionImportDetailResponse
from pulpcore.client.pulp_ansible.models.collection_metadata_response import CollectionMetadataResponse
from pulpcore.client.pulp_ansible.models.collection_namespace_response import CollectionNamespaceResponse
from pulpcore.client.pulp_ansible.models.collection_ref_response import CollectionRefResponse
from pulpcore.client.pulp_ansible.models.collection_response import CollectionResponse
from pulpcore.client.pulp_ansible.models.collection_summary_response import CollectionSummaryResponse
from pulpcore.client.pulp_ansible.models.collection_version_copy_move import CollectionVersionCopyMove
from pulpcore.client.pulp_ansible.models.collection_version_docs_response import CollectionVersionDocsResponse
from pulpcore.client.pulp_ansible.models.collection_version_list_response import CollectionVersionListResponse
from pulpcore.client.pulp_ansible.models.collection_version_response import CollectionVersionResponse
from pulpcore.client.pulp_ansible.models.collection_version_search_list import CollectionVersionSearchList
from pulpcore.client.pulp_ansible.models.collection_version_search_list_response import CollectionVersionSearchListResponse
from pulpcore.client.pulp_ansible.models.collection_version_signature_response import CollectionVersionSignatureResponse
from pulpcore.client.pulp_ansible.models.content_summary_response import ContentSummaryResponse
from pulpcore.client.pulp_ansible.models.copy import Copy
from pulpcore.client.pulp_ansible.models.galaxy_role_response import GalaxyRoleResponse
from pulpcore.client.pulp_ansible.models.galaxy_role_version_response import GalaxyRoleVersionResponse
from pulpcore.client.pulp_ansible.models.my_permissions_response import MyPermissionsResponse
from pulpcore.client.pulp_ansible.models.namespace_link import NamespaceLink
from pulpcore.client.pulp_ansible.models.namespace_link_response import NamespaceLinkResponse
from pulpcore.client.pulp_ansible.models.nested_role import NestedRole
from pulpcore.client.pulp_ansible.models.nested_role_response import NestedRoleResponse
from pulpcore.client.pulp_ansible.models.object_roles_response import ObjectRolesResponse
from pulpcore.client.pulp_ansible.models.paginated_collection_response_list import PaginatedCollectionResponseList
from pulpcore.client.pulp_ansible.models.paginated_collection_response_list_links import PaginatedCollectionResponseListLinks
from pulpcore.client.pulp_ansible.models.paginated_collection_response_list_meta import PaginatedCollectionResponseListMeta
from pulpcore.client.pulp_ansible.models.paginated_collection_version_list_response_list import PaginatedCollectionVersionListResponseList
from pulpcore.client.pulp_ansible.models.paginated_collection_version_search_list_response_list import PaginatedCollectionVersionSearchListResponseList
from pulpcore.client.pulp_ansible.models.paginated_galaxy_role_response_list import PaginatedGalaxyRoleResponseList
from pulpcore.client.pulp_ansible.models.paginated_galaxy_role_version_response_list import PaginatedGalaxyRoleVersionResponseList
from pulpcore.client.pulp_ansible.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList
from pulpcore.client.pulp_ansible.models.paginated_tag_response_list import PaginatedTagResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_collection_deprecated_response_list import PaginatedansibleAnsibleCollectionDeprecatedResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_distribution_response_list import PaginatedansibleAnsibleDistributionResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_namespace_metadata_response_list import PaginatedansibleAnsibleNamespaceMetadataResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_repository_response_list import PaginatedansibleAnsibleRepositoryResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_remote_response_list import PaginatedansibleCollectionRemoteResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_response_list import PaginatedansibleCollectionResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_mark_response_list import PaginatedansibleCollectionVersionMarkResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_response_list import PaginatedansibleCollectionVersionResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_signature_response_list import PaginatedansibleCollectionVersionSignatureResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_git_remote_response_list import PaginatedansibleGitRemoteResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_role_remote_response_list import PaginatedansibleRoleRemoteResponseList
from pulpcore.client.pulp_ansible.models.paginatedansible_role_response_list import PaginatedansibleRoleResponseList
from pulpcore.client.pulp_ansible.models.patched_collection import PatchedCollection
from pulpcore.client.pulp_ansible.models.patchedansible_ansible_distribution import PatchedansibleAnsibleDistribution
from pulpcore.client.pulp_ansible.models.patchedansible_ansible_repository import PatchedansibleAnsibleRepository
from pulpcore.client.pulp_ansible.models.patchedansible_collection_remote import PatchedansibleCollectionRemote
from pulpcore.client.pulp_ansible.models.patchedansible_git_remote import PatchedansibleGitRemote
from pulpcore.client.pulp_ansible.models.patchedansible_role_remote import PatchedansibleRoleRemote
from pulpcore.client.pulp_ansible.models.policy_enum import PolicyEnum
from pulpcore.client.pulp_ansible.models.repair import Repair
from pulpcore.client.pulp_ansible.models.repo_metadata_response import RepoMetadataResponse
from pulpcore.client.pulp_ansible.models.repository import Repository
from pulpcore.client.pulp_ansible.models.repository_add_remove_content import RepositoryAddRemoveContent
from pulpcore.client.pulp_ansible.models.repository_response import RepositoryResponse
from pulpcore.client.pulp_ansible.models.repository_version_response import RepositoryVersionResponse
from pulpcore.client.pulp_ansible.models.set_label import SetLabel
from pulpcore.client.pulp_ansible.models.set_label_response import SetLabelResponse
from pulpcore.client.pulp_ansible.models.tag_response import TagResponse
from pulpcore.client.pulp_ansible.models.unpaginated_collection_version_response import UnpaginatedCollectionVersionResponse
from pulpcore.client.pulp_ansible.models.unset_label import UnsetLabel
from pulpcore.client.pulp_ansible.models.unset_label_response import UnsetLabelResponse



# flake8: noqa

# import apis into api package
from pulpcore.client.pulp_ansible.api.ansible_collections_api import AnsibleCollectionsApi
from pulpcore.client.pulp_ansible.api.ansible_copy_api import AnsibleCopyApi
from pulpcore.client.pulp_ansible.api.api_plugin_ansible_search_collection_versions_api import ApiPluginAnsibleSearchCollectionVersionsApi
from pulpcore.client.pulp_ansible.api.api_roles_api import ApiRolesApi
from pulpcore.client.pulp_ansible.api.collection_import_api import CollectionImportApi
from pulpcore.client.pulp_ansible.api.content_collection_deprecations_api import ContentCollectionDeprecationsApi
from pulpcore.client.pulp_ansible.api.content_collection_marks_api import ContentCollectionMarksApi
from pulpcore.client.pulp_ansible.api.content_collection_signatures_api import ContentCollectionSignaturesApi
from pulpcore.client.pulp_ansible.api.content_collection_versions_api import ContentCollectionVersionsApi
from pulpcore.client.pulp_ansible.api.content_namespaces_api import ContentNamespacesApi
from pulpcore.client.pulp_ansible.api.content_roles_api import ContentRolesApi
from pulpcore.client.pulp_ansible.api.distributions_ansible_api import DistributionsAnsibleApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_api import PulpAnsibleApiApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_api import PulpAnsibleApiV3Api
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_artifacts_collections_api import PulpAnsibleApiV3ArtifactsCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collection_versions_all_api import PulpAnsibleApiV3CollectionVersionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_api import PulpAnsibleApiV3CollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_all_api import PulpAnsibleApiV3CollectionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_versions_api import PulpAnsibleApiV3CollectionsVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_versions_docs_blob_api import PulpAnsibleApiV3CollectionsVersionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_namespaces_api import PulpAnsibleApiV3NamespacesApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_client_configuration_api import PulpAnsibleApiV3PluginAnsibleClientConfigurationApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_all_collections_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsAllCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_all_versions_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsAllVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_artifacts_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsArtifactsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_index_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_index_versions_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_collections_index_versions_docs_blob_api import PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_plugin_ansible_content_namespaces_api import PulpAnsibleApiV3PluginAnsibleContentNamespacesApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_artifacts_collections_v3_api import PulpAnsibleArtifactsCollectionsV3Api
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_api import PulpAnsibleDefaultApiApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_api import PulpAnsibleDefaultApiV3Api
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_artifacts_collections_api import PulpAnsibleDefaultApiV3ArtifactsCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collection_versions_all_api import PulpAnsibleDefaultApiV3CollectionVersionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_api import PulpAnsibleDefaultApiV3CollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_all_api import PulpAnsibleDefaultApiV3CollectionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_versions_api import PulpAnsibleDefaultApiV3CollectionsVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_versions_docs_blob_api import PulpAnsibleDefaultApiV3CollectionsVersionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_namespaces_api import PulpAnsibleDefaultApiV3NamespacesApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_client_configuration_api import PulpAnsibleDefaultApiV3PluginAnsibleClientConfigurationApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_all_collections_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllCollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_all_versions_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_artifacts_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsArtifactsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_index_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_index_versions_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_collections_index_versions_docs_blob_api import PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_content_namespaces_api import PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_plugin_ansible_search_collection_versions_api import PulpAnsibleDefaultApiV3PluginAnsibleSearchCollectionVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_tags_api import PulpAnsibleTagsApi
from pulpcore.client.pulp_ansible.api.remotes_collection_api import RemotesCollectionApi
from pulpcore.client.pulp_ansible.api.remotes_git_api import RemotesGitApi
from pulpcore.client.pulp_ansible.api.remotes_role_api import RemotesRoleApi
from pulpcore.client.pulp_ansible.api.repositories_ansible_api import RepositoriesAnsibleApi
from pulpcore.client.pulp_ansible.api.repositories_ansible_versions_api import RepositoriesAnsibleVersionsApi
from pulpcore.client.pulp_ansible.api.versions_api import VersionsApi




# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.models.collection_version_search_list_response import CollectionVersionSearchListResponse

class TestCollectionVersionSearchListResponse(unittest.TestCase):
    """CollectionVersionSearchListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CollectionVersionSearchListResponse:
        """Test CollectionVersionSearchListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CollectionVersionSearchListResponse`
        """
        model = CollectionVersionSearchListResponse()
        if include_optional:
            return CollectionVersionSearchListResponse(
                repository = pulpcore.client.pulp_ansible.models.repository_response.RepositoryResponse(
                    pulp_href = '', 
                    prn = '', 
                    pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    versions_href = '', 
                    pulp_labels = {
                        'key' : ''
                        }, 
                    latest_version_href = '', 
                    name = '', 
                    description = '', 
                    retain_repo_versions = 1, 
                    remote = '', ),
                collection_version = pulpcore.client.pulp_ansible.models.collection_summary_response.CollectionSummaryResponse(
                    pulp_href = '', 
                    namespace = '', 
                    name = '', 
                    version = '', 
                    requires_ansible = '', 
                    pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    contents = [
                        null
                        ], 
                    dependencies = pulpcore.client.pulp_ansible.models.dependencies.dependencies(), 
                    description = '', 
                    tags = [
                        pulpcore.client.pulp_ansible.models.ansible/tag_response.ansible.TagResponse(
                            name = '', )
                        ], ),
                repository_version = '',
                namespace_metadata = pulpcore.client.pulp_ansible.models.ansible/ansible_namespace_metadata_response.ansible.AnsibleNamespaceMetadataResponse(
                    pulp_href = '', 
                    name = 'jUtgswwmejtcmosllnyulewqtzioitixmooyscslvdntrddzxydswqltrttwkqzbunjxbelktnh7nzn3yp7d8tmo8zxed012', 
                    company = '', 
                    email = '', 
                    description = '', 
                    resources = '', 
                    links = [
                        pulpcore.client.pulp_ansible.models.namespace_link_response.NamespaceLinkResponse(
                            url = '', 
                            name = '', )
                        ], 
                    avatar_sha256 = '', 
                    avatar_url = '', 
                    metadata_sha256 = '', ),
                is_highest = True,
                is_deprecated = True,
                is_signed = True
            )
        else:
            return CollectionVersionSearchListResponse(
                repository = pulpcore.client.pulp_ansible.models.repository_response.RepositoryResponse(
                    pulp_href = '', 
                    prn = '', 
                    pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    versions_href = '', 
                    pulp_labels = {
                        'key' : ''
                        }, 
                    latest_version_href = '', 
                    name = '', 
                    description = '', 
                    retain_repo_versions = 1, 
                    remote = '', ),
                collection_version = pulpcore.client.pulp_ansible.models.collection_summary_response.CollectionSummaryResponse(
                    pulp_href = '', 
                    namespace = '', 
                    name = '', 
                    version = '', 
                    requires_ansible = '', 
                    pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    contents = [
                        null
                        ], 
                    dependencies = pulpcore.client.pulp_ansible.models.dependencies.dependencies(), 
                    description = '', 
                    tags = [
                        pulpcore.client.pulp_ansible.models.ansible/tag_response.ansible.TagResponse(
                            name = '', )
                        ], ),
                namespace_metadata = pulpcore.client.pulp_ansible.models.ansible/ansible_namespace_metadata_response.ansible.AnsibleNamespaceMetadataResponse(
                    pulp_href = '', 
                    name = 'jUtgswwmejtcmosllnyulewqtzioitixmooyscslvdntrddzxydswqltrttwkqzbunjxbelktnh7nzn3yp7d8tmo8zxed012', 
                    company = '', 
                    email = '', 
                    description = '', 
                    resources = '', 
                    links = [
                        pulpcore.client.pulp_ansible.models.namespace_link_response.NamespaceLinkResponse(
                            url = '', 
                            name = '', )
                        ], 
                    avatar_sha256 = '', 
                    avatar_url = '', 
                    metadata_sha256 = '', ),
                is_highest = True,
                is_deprecated = True,
                is_signed = True,
        )
        """

    def testCollectionVersionSearchListResponse(self):
        """Test CollectionVersionSearchListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import List, Optional, Union
from typing_extensions import Annotated
from pulpcore.client.pulp_ansible.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulp_ansible.models.collection_version_response import CollectionVersionResponse
from pulpcore.client.pulp_ansible.models.paginated_collection_version_list_response_list import PaginatedCollectionVersionListResponseList

from pulpcore.client.pulp_ansible.api_client import ApiClient, RequestSerialized
from pulpcore.client.pulp_ansible.api_response import ApiResponse
from pulpcore.client.pulp_ansible.rest import RESTResponseType


class PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def delete(
        self,
        distro_base_path: StrictStr,
        name: StrictStr,
        namespace: StrictStr,
        version: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AsyncOperationResponse:
        """delete

        Trigger an asynchronous delete task

        :param distro_base_path: (required)
        :type distro_base_path: str
        :param name: (required)
        :type name: str
        :param namespace: (required)
        :type namespace: str
        :param version: (required)
        :type version: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_serialize(
            distro_base_path=distro_base_path,
            name=name,
            namespace=namespace,
            version=version,
            x_task_diagnostics=x_task_diagnostics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "AsyncOperationResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_with_http_info(
        self,
        distro_base_path: StrictStr,
        name: StrictStr,
        namespace: StrictStr,
        version: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AsyncOperationResponse]:
        """delete

        Trigger an asynchronous delete task

        :param distro_base_path: (required)
        :type distro_base_path: str
        :param name: (required)
        :type name: str
        :param namespace: (required)
        :type namespace: str
        :param version: (required)
        :type version: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_serialize(
            distro_base_path=distro_base_path,
            name=name,
            namespace=namespace,
            version=version,
            x_task_diagnostics=x_task_diagnostics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "AsyncOperationResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_without_preload_content(
        self,
        distro_base_path: StrictStr,
        name: StrictStr,
        namespace: StrictStr,
        version: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """delete

        Trigger an asynchronous delete task

        :param distro_base_path: (required)
        :type distro_base_path: str
        :param name: (required)
        :type name: str
        :param namespace: (required)
        :type namespace: str
        :param version: (required)
        :type version: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_serialize(
            distro_base_path=distro_base_path,
            name=name,
            namespace=namespace,
            version=version,
            x_task_diagnostics=x_task_diagnostics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "AsyncOperationResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_serialize(
        self,
        distro_base_path,
        name,
        namespace,
        version,
        x_task_diagnostics,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'X-Task-Diagnostics': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if distro_base_path is not None:
            _path_params['distro_base_path'] = distro_base_path
        if name is not None:
            _path_params['name'] = name
        if namespace is not None:
            _path_params['namespace'] = namespace
        if version is not None:
            _path_params['version'] = version
        # process the query parameters
        # process the header parameters
        if x_task_diagnostics is not None:
            _header_params['X-Task-Diagnostics'] = x_task_diagnostics
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'cookieAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list(
        self,
        distro_base_path: StrictStr,
        name: StrictStr,
        namespace: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        name2: Optional[StrictStr] = None,
        namespace2: Optional[StrictStr] = None,
        offset: Annotated[Optional[StrictInt], Field(description="The initial index from which to return the results.")] = None,
        ordering: Annotated[Optional[List[StrictStr]], Field(description="Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `authors` - Authors * `-authors` - Authors (descending) * `contents` - Contents * `-contents` - Contents (descending) * `dependencies` - Dependencies * `-dependencies` - Dependencies (descending) * `description` - Description * `-description` - Description (descending) * `docs_blob` - Docs blob * `-docs_blob` - Docs blob (descending) * `manifest` - Manifest * `-manifest` - Manifest (descending) * `files` - Files * `-files` - Files (descending) * `documentation` - Documentation * `-documentation` - Documentation (descending) * `homepage` - Homepage * `-homepage` - Homepage (descending) * `issues` - Issues * `-issues` - Issues (descending) * `license` - License * `-license` - License (descending) * `name` - Name * `-name` - Name (descending) * `namespace` - Namespace * `-namespace` - Namespace (descending) * `repository` - Repository * `-repository` - Repository (descending) * `requires_ansible` - Requires ansible * `-requires_ansible` - Requires ansible (descending) * `sha256` - Sha256 * `-sha256` - Sha256 (descending) * `version` - Version * `-version` - Version (descending) * `version_major` - Version major * `-version_major` - Version major (descending) * `version_minor` - Version minor * `-version_minor` - Version minor (descending) * `version_patch` - Version patch * `-version_patch` - Version patch (descending) * `version_prerelease` - Version prerelease * `-version_prerelease` - Version prerelease (descending) * `is_highest` - Is highest * `-is_highest` - Is highest (descending) * `search_vector` - Search vector * `-search_vector` - Search vector (descending) * `pk` - Pk * `-pk` - Pk (descending)")] = None,
        orphaned_for: Annotated[Optional[Union[StrictFloat, StrictInt]], Field(description="Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.")] = None,
        prn__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_href__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_id__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_label_select: Annotated[Optional[StrictStr], Field(description="Filter labels by search string")] = None,
        q: Optional[StrictStr] = None,
        repository_version: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        repository_version_added: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        repository_version_removed: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        tags: Annotated[Optional[StrictStr], Field(description="Filter by comma separate list of tags that must all be matched")] = None,
        version: Annotated[Optional[StrictStr], Field(description="Filter results where version matches value")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginatedCollectionVersionListResponseList:
        """list

        Returns paginated CollectionVersions list.

        :param distro_base_path: (required)
        :type distro_base_path: str
        :param name: (required)
        :type name: str
        :param namespace: (required)
        :type namespace: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param limit: Number of results to return per page.
        :type limit: int
        :param name2:
        :type name2: str
        :param namespace2:
        :type namespace2: str
        :param offset: The initial index from which to return the results.
        :type offset: int
        :param ordering: Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `authors` - Authors * `-authors` - Authors (descending) * `contents` - Contents * `-contents` - Contents (descending) * `dependencies` - Dependencies * `-dependencies` - Dependencies (descending) * `description` - Description * `-description` - Description (descending) * `docs_blob` - Docs blob * `-docs_blob` - Docs blob (descending) * `manifest` - Manifest * `-manifest` - Manifest (descending) * `files` - Files * `-files` - Files (descending) * `documentation` - Documentation * `-documentation` - Documentation (descending) * `homepage` - Homepage * `-homepage` - Homepage (descending) * `issues` - Issues * `-issues` - Issues (descending) * `license` - License * `-license` - License (descending) * `name` - Name * `-name` - Name (descending) * `namespace` - Namespace * `-namespace` - Namespace (descending) * `repository` - Repository * `-repository` - Repository (descending) * `requires_ansible` - Requires ansible * `-requires_ansible` - Requires ansible (descending) * `sha256` - Sha256 * `-sha256` - Sha256 (descending) * `version` - Version * `-version` - Version (descending) * `version_major` - Version major * `-version_major` - Version major (descending) * `version_minor` - Version minor * `-version_minor` - Version minor (descending) * `version_patch` - Version patch * `-version_patch` - Version patch (descending) * `version_prerelease` - Version prerelease * `-version_prerelease` - Version prerelease (descending) * `is_highest` - Is highest * `-is_highest` - Is highest (descending) * `search_vector` - Search vector * `-search_vector` - Search vector (descending) * `pk` - Pk * `-pk` - Pk (descending)
        :type ordering: List[str]
        :param orphaned_for: Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.
        :type orphaned_for: float
        :param prn__in: Multiple values may be separated by commas.
        :type prn__in: List[str]
        :param pulp_href__in: Multiple values may be separated by commas.
        :type pulp_href__in: List[str]
        :param pulp_id__in: Multiple values may be separated by commas.
        :type pulp_id__in: List[str]
        :param pulp_label_select: Filter labels by search string
        :type pulp_label_select: str
        :param q:
        :type q: str
        :param repository_version: Repository Version referenced by HREF/PRN
        :type repository_version: str
        :param repository_version_added: Repository Version referenced by HREF/PRN
        :type repository_version_added: str
        :param repository_version_removed: Repository Version referenced by HREF/PRN
        :type repository_version_removed: str
        :param tags: Filter by comma separate list of tags that must all be matched
        :type tags: str
        :param version: Filter results where version matches value
        :type version: str
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            distro_base_path=distro_base_path,
            name=name,
            namespace=namespace,
            x_task_diagnostics=x_task_diagnostics,
            limit=limit,
            name2=name2,
            namespace2=namespace2,
            offset=offset,
            ordering=ordering,
            orphaned_for=orphaned_for,
            prn__in=prn__in,
            pulp_href__in=pulp_href__in,
            pulp_id__in=pulp_id__in,
            pulp_label_select=pulp_label_select,
            q=q,
            repository_version=repository_version,
            repository_version_added=repository_version_added,
            repository_version_removed=repository_version_removed,
            tags=tags,
            version=version,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedCollectionVersionListResponseList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_with_http_info(
        self,
        distro_base_path: StrictStr,
        name: StrictStr,
        namespace: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        name2: Optional[StrictStr] = None,
        namespace2: Optional[StrictStr] = None,
        offset: Annotated[Optional[StrictInt], Field(description="The initial index from which to return the results.")] = None,
        ordering: Annotated[Optional[List[StrictStr]], Field(description="Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `authors` - Authors * `-authors` - Authors (descending) * `contents` - Contents * `-contents` - Contents (descending) * `dependencies` - Dependencies * `-dependencies` - Dependencies (descending) * `description` - Description * `-description` - Description (descending) * `docs_blob` - Docs blob * `-docs_blob` - Docs blob (descending) * `manifest` - Manifest * `-manifest` - Manifest (descending) * `files` - Files * `-files` - Files (descending) * `documentation` - Documentation * `-documentation` - Documentation (descending) * `homepage` - Homepage * `-homepage` - Homepage (descending) * `issues` - Issues * `-issues` - Issues (descending) * `license` - License * `-license` - License (descending) * `name` - Name * `-name` - Name (descending) * `namespace` - Namespace * `-namespace` - Namespace (descending) * `repository` - Repository * `-repository` - Repository (descending) * `requires_ansible` - Requires ansible * `-requires_ansible` - Requires ansible (descending) * `sha256` - Sha256 * `-sha256` - Sha256 (descending) * `version` - Version * `-version` - Version (descending) * `version_major` - Version major * `-version_major` - Version major (descending) * `version_minor` - Version minor * `-version_minor` - Version minor (descending) * `version_patch` - Version patch * `-version_patch` - Version patch (descending) * `version_prerelease` - Version prerelease * `-version_prerelease` - Version prerelease (descending) * `is_highest` - Is highest * `-is_highest` - Is highest (descending) * `search_vector` - Search vector * `-search_vector` - Search vector (descending) * `pk` - Pk * `-pk` - Pk (descending)")] = None,
        orphaned_for: Annotated[Optional[Union[StrictFloat, StrictInt]], Field(description="Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.")] = None,
        prn__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_href__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_id__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_label_select: Annotated[Optional[StrictStr], Field(description="Filter labels by search string")] = None,
        q: Optional[StrictStr] = None,
        repository_version: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        repository_version_added: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        repository_version_removed: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        tags: Annotated[Optional[StrictStr], Field(description="Filter by comma separate list of tags that must all be matched")] = None,
        version: Annotated[Optional[StrictStr], Field(description="Filter results where version matches value")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginatedCollectionVersionListResponseList]:
        """list

        Returns paginated CollectionVersions list.

        :param distro_base_path: (required)
        :type distro_base_path: str
        :param name: (required)
        :type name: str
        :param namespace: (required)
        :type namespace: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param limit: Number of results to return per page.
        :type limit: int
        :param name2:
        :type name2: str
        :param namespace2:
        :type namespace2: str
        :param offset: The initial index from which to return the results.
        :type offset: int
        :param ordering: Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `authors` - Authors * `-authors` - Authors (descending) * `contents` - Contents * `-contents` - Contents (descending) * `dependencies` - Dependencies * `-dependencies` - Dependencies (descending) * `description` - Description * `-description` - Description (descending) * `docs_blob` - Docs blob * `-docs_blob` - Docs blob (descending) * `manifest` - Manifest * `-manifest` - Manifest (descending) * `files` - Files * `-files` - Files (descending) * `documentation` - Documentation * `-documentation` - Documentation (descending) * `homepage` - Homepage * `-homepage` - Homepage (descending) * `issues` - Issues * `-issues` - Issues (descending) * `license` - License * `-license` - License (descending) * `name` - Name * `-name` - Name (descending) * `namespace` - Namespace * `-namespace` - Namespace (descending) * `repository` - Repository * `-repository` - Repository (descending) * `requires_ansible` - Requires ansible * `-requires_ansible` - Requires ansible (descending) * `sha256` - Sha256 * `-sha256` - Sha256 (descending) * `version` - Version * `-version` - Version (descending) * `version_major` - Version major * `-version_major` - Version major (descending) * `version_minor` - Version minor * `-version_minor` - Version minor (descending) * `version_patch` - Version patch * `-version_patch` - Version patch (descending) * `version_prerelease` - Version prerelease * `-version_prerelease` - Version prerelease (descending) * `is_highest` - Is highest * `-is_highest` - Is highest (descending) * `search_vector` - Search vector * `-search_vector` - Search vector (descending) * `pk` - Pk * `-pk` - Pk (descending)
        :type ordering: List[str]
        :param orphaned_for: Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.
        :type orphaned_for: float
        :param prn__in: Multiple values may be separated by commas.
        :type prn__in: List[str]
        :param pulp_href__in: Multiple values may be separated by commas.
        :type pulp_href__in: List[str]
        :param pulp_id__in: Multiple values may be separated by commas.
        :type pulp_id__in: List[str]
        :param pulp_label_select: Filter labels by search string
        :type pulp_label_select: str
        :param q:
        :type q: str
        :param repository_version: Repository Version referenced by HREF/PRN
        :type repository_version: str
        :param repository_version_added: Repository Version referenced by HREF/PRN
        :type repository_version_added: str
        :param repository_version_removed: Repository Version referenced by HREF/PRN
        :type repository_version_removed: str
        :param tags: Filter by comma separate list of tags that must all be matched
        :type tags: str
        :param version: Filter results where version matches value
        :type version: str
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            distro_base_path=distro_base_path,
            name=name,
            namespace=namespace,
            x_task_diagnostics=x_task_diagnostics,
            limit=limit,
            name2=name2,
            namespace2=namespace2,
            offset=offset,
            ordering=ordering,
            orphaned_for=orphaned_for,
            prn__in=prn__in,
            pulp_href__in=pulp_href__in,
            pulp_id__in=pulp_id__in,
            pulp_label_select=pulp_label_select,
            q=q,
            repository_version=repository_version,
            repository_version_added=repository_version_added,
            repository_version_removed=repository_version_removed,
            tags=tags,
            version=version,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedCollectionVersionListResponseList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_without_preload_content(
        self,
        distro_base_path: StrictStr,
        name: StrictStr,
        namespace: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        name2: Optional[StrictStr] = None,
        namespace2: Optional[StrictStr] = None,
        offset: Annotated[Optional[StrictInt], Field(description="The initial index from which to return the results.")] = None,
        ordering: Annotated[Optional[List[StrictStr]], Field(description="Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `authors` - Authors * `-authors` - Authors (descending) * `contents` - Contents * `-contents` - Contents (descending) * `dependencies` - Dependencies * `-dependencies` - Dependencies (descending) * `description` - Description * `-description` - Description (descending) * `docs_blob` - Docs blob * `-docs_blob` - Docs blob (descending) * `manifest` - Manifest * `-manifest` - Manifest (descending) * `files` - Files * `-files` - Files (descending) * `documentation` - Documentation * `-documentation` - Documentation (descending) * `homepage` - Homepage * `-homepage` - Homepage (descending) * `issues` - Issues * `-issues` - Issues (descending) * `license` - License * `-license` - License (descending) * `name` - Name * `-name` - Name (descending) * `namespace` - Namespace * `-namespace` - Namespace (descending) * `repository` - Repository * `-repository` - Repository (descending) * `requires_ansible` - Requires ansible * `-requires_ansible` - Requires ansible (descending) * `sha256` - Sha256 * `-sha256` - Sha256 (descending) * `version` - Version * `-version` - Version (descending) * `version_major` - Version major * `-version_major` - Version major (descending) * `version_minor` - Version minor * `-version_minor` - Version minor (descending) * `version_patch` - Version patch * `-version_patch` - Version patch (descending) * `version_prerelease` - Version prerelease * `-version_prerelease` - Version prerelease (descending) * `is_highest` - Is highest * `-is_highest` - Is highest (descending) * `search_vector` - Search vector * `-search_vector` - Search vector (descending) * `pk` - Pk * `-pk` - Pk (descending)")] = None,
        orphaned_for: Annotated[Optional[Union[StrictFloat, StrictInt]], Field(description="Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.")] = None,
        prn__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_href__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_id__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_label_select: Annotated[Optional[StrictStr], Field(description="Filter labels by search string")] = None,
        q: Optional[StrictStr] = None,
        repository_version: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        repository_version_added: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        repository_version_removed: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        tags: Annotated[Optional[StrictStr], Field(description="Filter by comma separate list of tags that must all be matched")] = None,
        version: Annotated[Optional[StrictStr], Field(description="Filter results where version matches value")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """list

        Returns paginated CollectionVersions list.

        :param distro_base_path: (required)
        :type distro_base_path: str
        :param name: (required)
        :type name: str
        :param namespace: (required)
        :type namespace: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param limit: Number of results to return per page.
        :type limit: int
        :param name2:
        :type name2: str
        :param namespace2:
        :type namespace2: str
        :param offset: The initial index from which to return the results.
        :type offset: int
        :param ordering: Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `authors` - Authors * `-authors` - Authors (descending) * `contents` - Contents * `-contents` - Contents (descending) * `dependencies` - Dependencies * `-dependencies` - Dependencies (descending) * `description` - Description * `-description` - Description (descending) * `docs_blob` - Docs blob * `-docs_blob` - Docs blob (descending) * `manifest` - Manifest * `-manifest` - Manifest (descending) * `files` - Files * `-files` - Files (descending) * `documentation` - Documentation * `-documentation` - Documentation (descending) * `homepage` - Homepage * `-homepage` - Homepage (descending) * `issues` - Issues * `-issues` - Issues (descending) * `license` - License * `-license` - License (descending) * `name` - Name * `-name` - Name (descending) * `namespace` - Namespace * `-namespace` - Namespace (descending) * `repository` - Repository * `-repository` - Repository (descending) * `requires_ansible` - Requires ansible * `-requires_ansible` - Requires ansible (descending) * `sha256` - Sha256 * `-sha256` - Sha256 (descending) * `version` - Version * `-version` - Version (descending) * `version_major` - Version major * `-version_major` - Version major (descending) * `version_minor` - Version minor * `-version_minor` - Version minor (descending) * `version_patch` - Version patch * `-version_patch` - Version patch (descending) * `version_prerelease` - Version prerelease * `-version_prerelease` - Version prerelease (descending) * `is_highest` - Is highest * `-is_highest` - Is highest (descending) * `search_vector` - Search vector * `-search_vector` - Search vector (descending) * `pk` - Pk * `-pk` - Pk (descending)
        :type ordering: List[str]
        :param orphaned_for: Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.
        :type orphaned_for: float
        :param prn__in: Multiple values may be separated by commas.
        :type prn__in: List[str]
        :param pulp_href__in: Multiple values may be separated by commas.
        :type pulp_href__in: List[str]
        :param pulp_id__in: Multiple values may be separated by commas.
        :type pulp_id__in: List[str]
        :param pulp_label_select: Filter labels by search string
        :type pulp_label_select: str
        :param q:
        :type q: str
        :param repository_version: Repository Version referenced by HREF/PRN
        :type repository_version: str
        :param repository_version_added: Repository Version referenced by HREF/PRN
        :type repository_version_added: str
        :param repository_version_removed: Repository Version referenced by HREF/PRN
        :type repository_version_removed: str
        :param tags: Filter by comma separate list of tags that must all be matched
        :type tags: str
        :param version: Filter results where version matches value
        :type version: str
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            distro_base_path=distro_base_path,
            name=name,
            namespace=namespace,
            x_task_diagnostics=x_task_diagnostics,
            limit=limit,
            name2=name2,
            namespace2=namespace2,
            offset=offset,
            ordering=ordering,
            orphaned_for=orphaned_for,
            prn__in=prn__in,
            pulp_href__in=pulp_href__in,
            pulp_id__in=pulp_id__in,
            pulp_label_select=pulp_label_select,
            q=q,
            repository_version=repository_version,
            repository_version_added=repository_version_added,
            repository_version_removed=repository_version_removed,
            tags=tags,
            version=version,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedCollectionVersionListResponseList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_serialize(
        self,
        distro_base_path,
        name,
        namespace,
        x_task_diagnostics,
        limit,
        name2,
        namespace2,
        offset,
        ordering,
        orphaned_for,
        prn__in,
        pulp_href__in,
        pulp_id__in,
        pulp_label_select,
        q,
        repository_version,
        repository_version_added,
        repository_version_removed,
        tags,
        version,
        fields,
        exclude_fields,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'X-Task-Diagnostics': 'csv',
            'ordering': 'csv',
            'prn__in': 'csv',
            'pulp_href__in': 'csv',
            'pulp_id__in': 'csv',
            'fields': 'multi',
            'exclude_fields': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if distro_base_path is not None:
            _path_params['distro_base_path'] = distro_base_path
        if name is not None:
            _path_params['name'] = name
        if namespace is not None:
            _path_params['namespace'] = namespace
        # process the query parameters
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if name2 is not None:
            
            _query_params.append(('name', name2))
            
        if namespace2 is not None:
            
            _query_params.append(('namespace', namespace2))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if ordering is not None:
            
            _query_params.append(('ordering', ordering))
            
        if orphaned_for is not None:
            
            _query_params.append(('orphaned_for', orphaned_for))
            
        if prn__in is not None:
            
            _query_params.append(('prn__in', prn__in))
            
        if pulp_href__in is not None:
            
            _query_params.append(('pulp_href__in', pulp_href__in))
            
        if pulp_id__in is not None:
            
            _query_params.append(('pulp_id__in', pulp_id__in))
            
        if pulp_label_select is not None:
            
            _query_params.append(('pulp_label_select', pulp_label_select))
            
        if q is not None:
            
            _query_params.append(('q', q))
            
        if repository_version is not None:
            
            _query_params.append(('repository_version', repository_version))
            
        if repository_version_added is not None:
            
            _query_params.append(('repository_version_added', repository_version_added))
            
        if repository_version_removed is not None:
            
            _query_params.append(('repository_version_removed', repository_version_removed))
            
        if tags is not None:
            
            _query_params.append(('tags', tags))
            
        if version is not None:
            
            _query_params.append(('version', version))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if exclude_fields is not None:
            
            _query_params.append(('exclude_fields', exclude_fields))
            
        # process the header parameters
        if x_task_diagnostics is not None:
            _header_params['X-Task-Diagnostics'] = x_task_diagnostics
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'cookieAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def read(
        self,
        distro_base_path: StrictStr,
        name: StrictStr,
        namespace: StrictStr,
        version: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CollectionVersionResponse:
        """read

        Returns a CollectionVersion object.

        :param distro_base_path: (required)
        :type distro_base_path: str
        :param name: (required)
        :type name: str
        :param namespace: (required)
        :type namespace: str
        :param version: (required)
        :type version: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._read_serialize(
            distro_base_path=distro_base_path,
            name=name,
            namespace=namespace,
            version=version,
            x_task_diagnostics=x_task_diagnostics,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CollectionVersionResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def read_with_http_info(
        self,
        distro_base_path: StrictStr,
        name: StrictStr,
        namespace: StrictStr,
        version: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CollectionVersionResponse]:
        """read

        Returns a CollectionVersion object.

        :param distro_base_path: (required)
        :type distro_base_path: str
        :param name: (required)
        :type name: str
        :param namespace: (required)
        :type namespace: str
        :param version: (required)
        :type version: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._read_serialize(
            distro_base_path=distro_base_path,
            name=name,
            namespace=namespace,
            version=version,
            x_task_diagnostics=x_task_diagnostics,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CollectionVersionResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def read_without_preload_content(
        self,
        distro_base_path: StrictStr,
        name: StrictStr,
        namespace: StrictStr,
        version: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """read

        Returns a CollectionVersion object.

        :param distro_base_path: (required)
        :type distro_base_path: str
        :param name: (required)
        :type name: str
        :param namespace: (required)
        :type namespace: str
        :param version: (required)
        :type version: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._read_serialize(
            distro_base_path=distro_base_path,
            name=name,
            namespace=namespace,
            version=version,
            x_task_diagnostics=x_task_diagnostics,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CollectionVersionResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _read_serialize(
        self,
        distro_base_path,
        name,
        namespace,
        version,
        x_task_diagnostics,
        fields,
        exclude_fields,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'X-Task-Diagnostics': 'csv',
            'fields': 'multi',
            'exclude_fields': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if distro_base_path is not None:
            _path_params['distro_base_path'] = distro_base_path
        if name is not None:
            _path_params['name'] = name
        if namespace is not None:
            _path_params['namespace'] = namespace
        if version is not None:
            _path_params['version'] = version
        # process the query parameters
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if exclude_fields is not None:
            
            _query_params.append(('exclude_fields', exclude_fields))
            
        # process the header parameters
        if x_task_diagnostics is not None:
            _header_params['X-Task-Diagnostics'] = x_task_diagnostics
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth', 
            'cookieAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.api.pulp_ansible_default_api_v3_collections_api import PulpAnsibleDefaultApiV3CollectionsApi


class TestPulpAnsibleDefaultApiV3CollectionsApi(unittest.TestCase):
    """PulpAnsibleDefaultApiV3CollectionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PulpAnsibleDefaultApiV3CollectionsApi()

    def tearDown(self) -> None:
        pass

    def test_delete(self) -> None:
        """Test case for delete

        """
        pass

    def test_list(self) -> None:
        """Test case for list

        """
        pass

    def test_read(self) -> None:
        """Test case for read

        """
        pass

    def test_update(self) -> None:
        """Test case for update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from pulpcore.client.pulp_ansible.models.ansible_tag_response import AnsibleTagResponse
from typing import Optional, Set
from typing_extensions import Self


class OneOf:
    @staticmethod
    def from_dict(obj, *args, **kwargs):
        """Noop override to fix missing OneOf import/implementation."""
        return obj


class CollectionSummaryResponse(BaseModel):
    """
    Collection Version serializer without docs blob.
    """ # noqa: E501
    pulp_href: Optional[StrictStr] = None
    namespace: Optional[Annotated[str, Field(strict=True, max_length=64)]] = Field(default=None, description="The namespace of the collection.")
    name: Optional[Annotated[str, Field(strict=True, max_length=64)]] = Field(default=None, description="The name of the collection.")
    version: Optional[Annotated[str, Field(strict=True, max_length=128)]] = Field(default=None, description="The version of the collection.")
    requires_ansible: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="The version of Ansible required to use the collection. Multiple versions can be separated with a comma.")
    pulp_created: Optional[datetime] = Field(default=None, description="Timestamp of creation.")
    contents: Optional[List[Any]] = Field(default=None, description="A JSON field with data about the contents.")
    dependencies: Optional[Dict[str, Any]] = Field(default=None, description="A dict declaring Collections that this collection requires to be installed for it to be usable.")
    description: Optional[StrictStr] = Field(default=None, description="A short summary description of the collection.")
    tags: Optional[List[AnsibleTagResponse]] = None
    __properties: ClassVar[List[str]] = ["pulp_href", "namespace", "name", "version", "requires_ansible", "pulp_created", "contents", "dependencies", "description", "tags"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CollectionSummaryResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pulp_href",
            "namespace",
            "name",
            "version",
            "requires_ansible",
            "pulp_created",
            "contents",
            "dependencies",
            "description",
            "tags",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        # set to None if requires_ansible (nullable) is None
        # and model_fields_set contains the field
        if self.requires_ansible is None and "requires_ansible" in self.model_fields_set:
            _dict['requires_ansible'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CollectionSummaryResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pulp_href": obj.get("pulp_href"),
            "namespace": obj.get("namespace"),
            "name": obj.get("name"),
            "version": obj.get("version"),
            "requires_ansible": obj.get("requires_ansible"),
            "pulp_created": obj.get("pulp_created"),
            "contents": obj.get("contents"),
            "dependencies": obj.get("dependencies"),
            "description": obj.get("description"),
            "tags": [AnsibleTagResponse.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None
        })
        return _obj


